from dataclasses import dataclass
from typing import Any, Dict


@dataclass(slots=True, frozen=True)
class Target:
    name: str
    connector_config: Dict[str, Any]

    def make_writer(self, **writer_args):
        from ..databases import GraphDatabaseWriter

        return GraphDatabaseWriter.from_file_data(
            **writer_args, **self.connector_config
        )



from .database_connector import DatabaseConnector
from .debounced_ingest_strategy import DebouncedIngestStrategy
from .writer import GraphDatabaseWriter

__all__ = ("GraphDatabaseWriter", "DebouncedIngestStrategy", "DatabaseConnector")
